diff --git a/wp-admin/includes/class-wp-comments-list-table.php b/wp-admin/includes/class-wp-comments-list-table.php
index c4cc308b3e..4efe76dd41 100644
--- a/wp-admin/includes/class-wp-comments-list-table.php
+++ b/wp-admin/includes/class-wp-comments-list-table.php
@@ -868,9 +868,14 @@ class WP_Comments_List_Table extends WP_List_Table {
}
/**
* @param WP_Comment $comment The comment object.
*/
- public function column_cb( $comment ) {
+ public function column_cb( $item ) {
+ // Restores the more descriptive, specific name for use within this method.
+ $comment = $item;
+
if ( $this->user_can ) {
?>
@@ -868,9 +868,14 @@ class WP_Comments_List_Table extends WP_List_Table {
}
/**
- * @param WP_Comment $comment The comment object.
+ * @since 5.9.0 Renamed `$comment` to `$item` to match parent class for PHP 8 named parameter support.
+ *
+ * @param WP_Comment $item The comment object.
*/
diff --git a/wp-admin/includes/class-wp-links-list-table.php b/wp-admin/includes/class-wp-links-list-table.php
index 21d4724e62..8c2d06bb2c 100644
--- a/wp-admin/includes/class-wp-links-list-table.php
+++ b/wp-admin/includes/class-wp-links-list-table.php
@@ -166,10 +166,14 @@ class WP_Links_List_Table extends WP_List_Table {
* Handles the checkbox column output.
*
* @since 4.3.0
+ * @since 5.9.0 Renamed `$link` to `$item` to match parent class for PHP 8 named parameter support.
*
* @param object $link The current link object.
*/
- public function column_cb( $link ) {
+ public function column_cb( $item ) {
+ // Restores the more descriptive, specific name for use within this method.
+ $link = $item;
+
?>
@@ -166,10 +166,14 @@ class WP_Links_List_Table extends WP_List_Table {
*
- * @param object $link The current link object.
+ * @param object $item The current link object.
*/